﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ChartWithTwoSeries
{
  /// <summary>
  /// Interaktionslogik für MainWindow.xaml
  /// </summary>
  public partial class MainWindow : Window
  {
    private const int NUMBER_OF_DATA_POINTS = 3648;

    private List<ChartViewModel> m_ChartViewModels;

    private List<DataPoint> m_DataPoints1 = new List<DataPoint>(NUMBER_OF_DATA_POINTS);
    private List<DataPoint> m_DataPoints2 = new List<DataPoint>(NUMBER_OF_DATA_POINTS);

    public delegate double CalcYDelegate(double x, double c);

    public MainWindow()
    {
      this.m_ChartViewModels = new List<ChartViewModel>
      {
        this.Resources["DataSource1"] as ChartViewModel,
        this.Resources["DataSource2"] as ChartViewModel
      };

      for (int i = 0; i < NUMBER_OF_DATA_POINTS; i++)
      {
        DataPoint point1 = new DataPoint();
        m_DataPoints1.Add(point1);
        m_ChartViewModels[0].Data.Add(point1);

        DataPoint point2 = new DataPoint();
        m_DataPoints2.Add(point2);
        m_ChartViewModels[1].Data.Add(point2);
      }

      CalcYDelegate calcSinusYDelegate = new CalcYDelegate(calcSinusY);

      generateData(m_DataPoints1, calcSinusYDelegate);

      CalcYDelegate calcCosinusYDelegate = new CalcYDelegate(calcCosinusY);

      generateData(m_DataPoints2, calcCosinusYDelegate);

      InitializeComponent();

      // I don't want to set the context here:
      //this.DataChart.DataContext = m_ChartViewModel;
    }

    static double calcSinusY(double x, double c)
    {
      return Math.Sin(x * c);
    }

    static double calcCosinusY(double x, double c)
    {
      return Math.Cos(x * c);
    }

    private void generateData(List<DataPoint> points, CalcYDelegate calcYDelegate)
    {
      double x = 0.0;
      double y = 0.0;
      double c = 2.0 / ( (double)points.Count() );

      foreach (DataPoint point in points)
      {
        x += 1.0;

        y = calcYDelegate(x, c);

        point.X = x;
        point.Y = y;
      }

    }
  }
}
